<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>Version %1</source>
        <translation>Верзија: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 је слободан софтвер, али његов развој одузима драгоцено време.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Молимо да &lt;a href=&apos;%1&apos;&gt;донацијама&lt;/a&gt; подржите даљи развој програма %2.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Под &lt;a href=&apos;%1&apos;&gt;ГНУовом Општом Јавном Лиценцом&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Затвори</translation>
    </message>
    <message>
        <source>About</source>
        <translation>О програму</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Све што сте желели да знате о програму %1, а нисте се усудили да питате</translation>
    </message>
    <message>
        <source>You may want to try my other apps as well:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1, a YouTube app</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1, a YouTube music player</source>
        <translation>%1, музички плејер за Јутјуб</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AlbumInfo</name>
    <message>
        <source>Buy on %1</source>
        <translation>Купи на %1</translation>
    </message>
    <message>
        <source>Read more</source>
        <translation>Сазнајте више</translation>
    </message>
</context>
<context>
    <name>ArtistInfo</name>
    <message>
        <source>Read more</source>
        <translation>Сазнајте више</translation>
    </message>
</context>
<context>
    <name>BreadcrumbWidget</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Назад</translation>
    </message>
    <message>
        <source>Go back</source>
        <translation>Иде уназад</translation>
    </message>
</context>
<context>
    <name>ChooseFolderView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 needs to scan your music collection.</source>
        <translation>%1 треба да претражи вашу збирку музике.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>Use iTunes collection</source>
        <translation>Користи ајТјунсову збирку</translation>
    </message>
    <message>
        <source>Use %1</source>
        <translation>Користи %1</translation>
    </message>
    <message>
        <source>Choose a folder...</source>
        <translation>Изаберите фасциклу...</translation>
    </message>
    <message>
        <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>If you have privacy concerns about this you can quit now.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Where&apos;s your music collection?</source>
        <translation>Где вам је збирка музике?</translation>
    </message>
    <message>
        <source>Select the location of your music collection.</source>
        <translation>Изаберите локацију ваше збирке музике.</translation>
    </message>
    <message>
        <source>Locate your collection</source>
        <translation>Лоцирајет вашу збирку</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Очисти</translation>
    </message>
</context>
<context>
    <name>CollectionScanner</name>
    <message>
        <source>A scanning task is already running</source>
        <translation>Претраживање је већ покренуто</translation>
    </message>
</context>
<context>
    <name>CollectionScannerView</name>
    <message>
        <source>%1 is scanning your music collection.</source>
        <translation>%1 претражује вашу збирку музике.</translation>
    </message>
    <message>
        <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>This will take time depending on your collection size and network speed.</source>
        <translation>Ово ће потрајати, зависно од величине збирке и брзине мреже.</translation>
    </message>
    <message>
        <source>Go grab a coffee</source>
        <translation>Скувајте кафицу.</translation>
    </message>
</context>
<context>
    <name>DemoStartupView</name>
    <message>
        <source>Please license %1</source>
        <translation>Молимо да купите %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Показна верзија је истекла.</translation>
    </message>
    <message>
        <source>This demo will expire in %1 days.</source>
        <translation>Верзија ће истећи за %1 дана.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Куповином пуне верзије ћете уједно и подржати мој рад на програму %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Користи показну верзију</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Преузмите пуну верзију</translation>
    </message>
    <message>
        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DropArea</name>
    <message>
        <source>Drop here to append to the playlist</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FinderWidget</name>
    <message>
        <source>Artists</source>
        <translation>Извођачи</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Албуми</translation>
    </message>
    <message>
        <source>Folders</source>
        <translation>Фасцикле</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Пусти</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Паузирај</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Пусти или паузирај</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Заустави</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Зауставља пуштање након тренутне нумере</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Следећа нумера</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Претходна нумера</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Појачај</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Утишај</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Искључи звук</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Пемотај унапред</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Премотај уназад</translation>
    </message>
</context>
<context>
    <name>LastFm</name>
    <message>
        <source>Authentication failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LastFmLoginDialog</name>
    <message>
        <source>Log in to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Signup for a %1 account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Назад</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Иди на претходни приказ</translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation>&amp;Подаци</translation>
    </message>
    <message>
        <source>Show information about the current track</source>
        <translation>Приказује податке о тренутној нумери</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>П&amp;ретходна</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Иде на претходну нумеру</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Следећа</translation>
    </message>
    <message>
        <source>Skip to the next track</source>
        <translation>Иде на следећу нумеру</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Пусти</translation>
    </message>
    <message>
        <source>Start playback</source>
        <translation>Започиње пуштање</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Цео екран</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Целоекрански приказ</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Уклони</translation>
    </message>
    <message>
        <source>Remove the selected tracks from the playlist</source>
        <translation>Уклања означене нумере из плејлисте</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Помери на&amp;више</translation>
    </message>
    <message>
        <source>Move up the selected tracks in the playlist</source>
        <translation>Помера изабране нумере у навише у листи</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Помери на&amp;ниже</translation>
    </message>
    <message>
        <source>Move down the selected tracks in the playlist</source>
        <translation>Помера изабране нумере у листи наниже</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Напусти</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Ћао</translation>
    </message>
    <message>
        <source>&amp;Change collection folder...</source>
        <translation>&amp;Измени фасциклу збирке...</translation>
    </message>
    <message>
        <source>Choose a different music collection folder</source>
        <translation>Изабира другу фасциклу збирке</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Веб сајт</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 на вебу</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Дајте &amp;донацију</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Молимо да подржите даљи развој програма %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;О програму</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Подаци о програму %1</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Очисти</translation>
    </message>
    <message>
        <source>Remove all tracks from the playlist</source>
        <translation>Уклања све нумере из листе</translation>
    </message>
    <message>
        <source>&amp;Shuffle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Random playlist mode</source>
        <translation>Насумични режим листе</translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation>&amp;Понављај</translation>
    </message>
    <message>
        <source>Play first song again after all songs are played</source>
        <translation>Поново пушта листу кад стигне до краја</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Угаси звук</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>Про&amp;грам</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Пуштање</translation>
    </message>
    <message>
        <source>Play&amp;list</source>
        <translation>Плеј&amp;листа</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>Прика&amp;з</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Помоћ</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Притисните %1 да појачате, односно %2 да утишате звук</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Отварам %1</translation>
    </message>
    <message>
        <source>Updating collection...</source>
        <translation>Ажурирам збирку</translation>
    </message>
    <message>
        <source>Updating collection - %1%</source>
        <translation>Ажурирам збирку — %1%</translation>
    </message>
    <message>
        <source>Collection updated</source>
        <translation>Збирка је ажурирана</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>тална грешка: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Преостало време: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Звуке је искључен</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Звук је поново укључен</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Преузмите пуну верзију</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update</source>
        <translation>Ажурирај</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Прозор</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Минимизуј</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Затвори</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Купите %1....</translation>
    </message>
    <message>
        <source>&amp;Stop After This Track</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Scrobbling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Send played tracks titles to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Log Out from %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Drop items here</source>
        <translation>Овде превуците ставке</translation>
    </message>
    <message>
        <source>Playlist finished</source>
        <translation>Крај плејлисте</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Ово је тек демо верзија програма %1.</translation>
    </message>
    <message>
        <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
        <translation>Дозвољава вам да пустите пар нумера како би испробали програм и оценили да ли вам одговара.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Настави</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Преузмите пуну верзију</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>This demo is limited to only %1 tracks in the playlist.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistView</name>
    <message>
        <source>Playlist is empty</source>
        <translation>Плејлиста је празна</translation>
    </message>
    <message>
        <source>%1 tracks - Total length is %2</source>
        <translation>%1 нумера — укупно трајање %2</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Претражи</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Your search had no results.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TrackListView</name>
    <message>
        <source>Tracks</source>
        <translation>Нумере</translation>
    </message>
</context>
</TS>